@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"C:/msys64/clangarm64/bin/python.exe",
 
         # Package versions
-        contourpy_version="1.2.1",
+        contourpy_version="1.3.0",
         meson_version="1.5.1",
         mesonpy_version="0.16.0",
-        pybind11_version="2.13.1",
+        pybind11_version="2.13.5",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-4oto9so9/lib/contourpy/util",
+        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/lib/contourpy/util",
         source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-4oto9so9/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
